@@ -1,13 +1,10 @@
 import re
 
-from rigidanalytics_tracker import Tracker
+from rigidanalytics_tracker.tracker import Tracker
 
 
 class DjangoTracker(Tracker):
 
-    def __init__(self):
-        self.init_tracker()
-
     @property
     def app_settings(self):
         from django.conf import settings
@@ -39,7 +36,8 @@ class DjangoTracker(Tracker):
         return self.request.build_absolute_uri()
 
     def get_session_id(self):
-        return self.request.session.session_key
+        return self.request.session.setdefault(
+            "ra_session_id", super(DjangoTracker, self).get_session_id())
 
     def get_response_data(self):
         return {
